pub fn build_provider(
mnemonic: impl AsRef<str>,
account_index: u32,
url: Url,
poll_interval: Option<Duration>,
) -> HttpProviderWithWalletExpand description
a handy thin wrapper around wallet builder and provider builder that directly
returns an instantiated Provider with default fillers with wallet, ready to send tx