pub async fn fetch_stake_table_for_stake_table_storage_migration(
l1_client: L1Client,
stake_table_address: Address,
) -> Result<(U256, Vec<InitialCommission>)>Expand description
Read stake table data from L1 StakeTable V1 events for V2 migration
Returns both the active stake and commissions needed for StakeTable V2 initialization. Assumes an infura RPC is used, otherwise it may hit other rate limits.